@@ -12,6 +12,7 @@ use URI::QueryParam (); # part of URI, to add helper methods
 use App::Netdisco::Web::AuthN;
 use App::Netdisco::Web::Search;
 use App::Netdisco::Web::Device;
+use App::Netdisco::Web::Report;
 use App::Netdisco::Web::TypeAhead;
 use App::Netdisco::Web::PortControl;
 
@@ -23,7 +24,9 @@ sub _load_web_plugins {
         unless $plugin =~ m/^\+/;
       $plugin =~ s/^\+//;
 
+      debug "loading Netdisco plugin $plugin";
       eval "require $plugin";
+      error $@ if $@;
   }
 }
 
