@@ -44,7 +44,8 @@ function do_search (event, tab) {
 
   // update browser search history with the new query.
   // however if it's the same tab, this is a *replace* of the query url.
-  if (window.History && window.History.enabled) {
+  // and just skip this bit if it's the reports display.
+  if (path != 'report' && window.History && window.History.enabled) {
     is_from_history_plugin = 1;
     window.History.replaceState(
       {name: tab, fields: $(form).serializeArray()},
